<style type="text/css">
body {
    background-color: #4d4d4d;
    color: #1d1d1d;
    font-family: system, -apple-system, -webkit-system-font, SFNSText, "Segoe UI", "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-size: 14px;
    line-height: 24px;
    margin: 0px 0px 0px 0px;
    padding: 0px 0px 0px 0px;
    text-align: left;
    word-break: break-word;
}

body > .container {
    background-color: #4d4d4d;
    color: #1d1d1d;
    font-family: system, -apple-system, -webkit-system-font, SFNSText, "Segoe UI", "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-size: 14px;
    line-height: 24px;
    text-align: left;
}

h1 {
    color: #1d1d1d;
    font-size: 28px;
    font-weight: 500;
    margin-bottom: 26px;
    margin-top: 38px;
}

h2 {
    color: #1d1d1d;
    font-size: 22px;
    font-weight: 500;
    margin-bottom: 20px;
    margin-top: 38px;
}

h3 {
    color: #1d1d1d;
    font-size: 20px;
    font-weight: 500;
    margin-bottom: 16px;
    margin-top: 24px;
}

h4 {
    color: #1d1d1d;
    font-size: 18px;
    font-weight: 500;
    margin-bottom: 10px;
    margin-top: 20px;
}

h5 {
    color: #1d1d1d;
    font-size: 15px;
    font-weight: 500;
    margin-bottom: 8px;
    margin-top: 16px;
}

a {
    color: #1b75bb;
    padding-bottom: 1px;
    text-decoration: none;
}

a:hover {
    border-bottom: 1px solid #1b75bb;
}

em {
    letter-spacing: 0.3px;
}

ul {
    margin: 0px 0px 0px 0px;
    padding-left: 16px;
}

ul li {
    margin: 6px 0px 6px 0px;
}

code {
    background-color: #f4f4f4;
    font-family: "SFMono-Regular", Consolas, "Liberation Mono", Menlo, Courier, monospace;
    font-size: 85%;
    padding: 2px 6px 2px 6px;
}

img {
    max-width: 100%;
}

.title {
    margin-bottom: 24px;
    margin-top: 24px;
    text-align: center;
}

.title.no-margin {
    margin-bottom: 12px;
}

.subtitle {
    margin-top: 0px;
    text-align: center;
    font-size: 20px;
}

.container {
    background-color: #4d4d4d;
    margin: 0px auto 0px auto;
    padding: 48px 0px 48px 0px;
}

.container > .paper {
    background-color: #ffffff;
    border: 1px solid #000000;
    box-shadow: 0px 0px 24px #000000;
    box-sizing: border-box;
    margin: 0px auto 0px auto;
    max-width: 100%;
    padding: 42px 72px 42px 72px;
    width: 664px;
}

.footer {
    font-size: 10px;
    line-height: 16px;
    margin-top: 48px;
    text-align: right;
}

.logo-url {
    margin: 24px 0px 32px 0px;
    text-align: center;
}

.logo-url > img {
    max-width: 280px;
}
</style>

<style type="text/css" media="only screen and (max-width: 480px)">
@media only screen and (max-width: 480px) {
    body {
        background-color: #ffffff !important;
    }

    body > .container {
        background-color: #ffffff !important;
    }

    .container {
        padding: 0px 0px 0px 0px !important;
    }

    .container > .paper {
        border: none !important;
        box-shadow: none !important;
        max-width: 100% !important;
        padding: 0px 24px 0px 24px !important;
        width: 480px !important;
    }
}
</style>
